import { BaseComponent } from '../base.component';
import { Injector, OnInit, NgZone, EventEmitter } from '@angular/core';
import { MatDialog } from '@angular/material/dialog';
import { ScrollDispatcher } from '@angular/cdk/scrolling';
import { ConfigActions, PictureparkUIConfiguration } from '../../../configuration';
import { IEntityBase, ThumbnailSize, SearchFacade, SearchInputState, AggregationResult } from '@picturepark/sdk-v1-angular';
import { SelectionService } from '../../services/selection/selection.service';
import { ISortItem } from './interfaces/sort-item';
import { TranslationService } from '../../services/translations/translation.service';
import { IBrowserView } from './interfaces/browser-view';
import { Observable } from 'rxjs';
export declare abstract class BaseBrowserComponent<TEntity extends IEntityBase> extends BaseComponent implements OnInit {
    protected componentName: string;
    protected injector: Injector;
    facade: SearchFacade<TEntity, SearchInputState>;
    protected get scrollDispatcher(): ScrollDispatcher;
    protected get ngZone(): NgZone;
    protected get translationService(): TranslationService;
    get selectionService(): SelectionService<TEntity>;
    protected get dialog(): MatDialog;
    self: BaseBrowserComponent<TEntity>;
    protected pictureParkUIConfig: PictureparkUIConfiguration;
    configActions: ConfigActions;
    isLoading: boolean;
    items: TEntity[];
    isAscending: boolean | null;
    activeSortingType: ISortItem;
    sortingTypes: ISortItem[];
    views: IBrowserView[];
    activeView: IBrowserView;
    activeThumbnailSize: ThumbnailSize;
    protected scrollDebounceTime: number;
    selectedItemsChange: EventEmitter<TEntity[]>;
    previewItemChange: EventEmitter<TEntity>;
    private _selectedItems;
    private lastSelectedIndex;
    private lastRangeSelection;
    totalResults$: Observable<number>;
    items$: Observable<TEntity[]>;
    aggregationResults$: Observable<AggregationResult[] | undefined>;
    abstract init(): Promise<void>;
    abstract initSort(): void;
    abstract onScroll(): void;
    abstract checkContains(elementClassName: string): boolean;
    constructor(componentName: string, injector: Injector, facade: SearchFacade<TEntity, SearchInputState>);
    ngOnInit(): Promise<void>;
    get selectedItems(): TEntity[];
    set selectedItems(items: TEntity[]);
    trackByItem(index: number, item: TEntity): string;
    update(): void;
    loadData(): Observable<any> | undefined;
    protected prepareData(items: TEntity[]): void;
    /**
     * Click event to trigger selection (ctrl + shift click)
     */
    itemClicked(event: MouseEvent, index: number, presist?: boolean): void;
    itemPressed(event: Event, index: number): void;
    toggleItems(isSelected: boolean): void;
    previewItem(item: TEntity): void;
    setSort(newValue: ISortItem, isAscending: boolean, reload?: boolean): void;
    changeView(view: IBrowserView): void;
    handleClick(event: any): void;
}
